/* This file was generated by syncqt. */
#ifndef QT_QTLOTTIEVECTORIMAGEHELPERS_VERSION_H
#define QT_QTLOTTIEVECTORIMAGEHELPERS_VERSION_H

#define QTLOTTIEVECTORIMAGEHELPERS_VERSION_STR "6.10.2"

#define QTLOTTIEVECTORIMAGEHELPERS_VERSION 0x0601002

#endif // QT_QTLOTTIEVECTORIMAGEHELPERS_VERSION_H
